@@ -260,21 +260,9 @@ void url_capplet_cancel(void) {
 static void
 url_capplet_help(GtkWidget *widget, gpointer data)
 {
-  gchar *tmp;
-
-  tmp = gnome_help_file_find_file ("control-center", "doc-handlers.html#GCCURL");
-  if (tmp) {
-    gnome_help_goto(0, tmp);
-    g_free(tmp);
-  } else {
-    GtkWidget *mbox;
-
-    mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
-				 GNOME_MESSAGE_BOX_ERROR,
-				 _("Close"), NULL);
-    
-    gtk_widget_show(mbox);
-  }
+    GnomeHelpMenuEntry help_entry= {"control-center",
+    "doc-handlers.html#GCCURL"};
+    gnome_help_display (NULL, &help_entry);
 }
 
 void set_handler(GtkEntry *entry) {
